/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	JavaScript functions for XML documents

	@author Nicklas
	@version 2.15
*/
var Xml = new XmlClass();
function XmlClass()
{
	/**
		Create a new empty XML document
		@param rootTag The root tag in the xml document
		@return A Document object
	*/
	this.createDocument = function(rootTag)
	{
		var doc;
		if (document.implementation && document.implementation.createDocument)
		{
			doc = document.implementation.createDocument(null, rootTag, null);
		}
		else
		{
			doc = new ActiveXObject("MSXML2.DOMDocument"); 
			var xml = '<' + rootTag + '/>';
			doc.loadXML(xml);
		}
		return doc;
	}
	
	/**
		Add a tag as a child node in the document.
		@param node The parent node
		@param name The child tag name
		@param value The text value of the tag (or null if not given)
		@return The new node object
	*/
	this.addTag = function(node, name, value)
	{
		var childNode = node.ownerDocument.createElement(name);
		node.appendChild(childNode);
		if (value)
		{
			var textNode = node.ownerDocument.createTextNode(value);
			childNode.appendChild(textNode);
		}
		return childNode;
	}
	
	/**
		Set an attribute for a node.
		@param node The node
		@param name The name of the attribute
		@param value The value of the attribute
	*/
	this.setAttribute = function(node, name, value)
	{
		node.setAttribute(name, value);
	}
	
	/**
		Convert an XML Document object to it's string representation.
		@param document The document object
		@return An xml string
	*/
	this.toString = function(document)
	{
		var xml = document.xml;
		if (!xml)
		{
			xml = new XMLSerializer().serializeToString(document);
		}
		return xml;
	}
}

